/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.registry.nacos;

import org.apache.servicecomb.config.DataCenterProperties;
import org.apache.servicecomb.registry.RegistrationId;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;

@Configuration
public class NacosConfiguration {
  @Bean
  @ConfigurationProperties(prefix = NacosConst.NACOS_REGISTRY_PREFIX)
  public NacosDiscoveryProperties nacosDiscoveryProperties() {
    return new NacosDiscoveryProperties();
  }

  @Bean
  public NacosRegistration nacosRegistration(
      DataCenterProperties dataCenterProperties,
      @Qualifier("nacosDiscoveryProperties") NacosDiscoveryProperties nacosDiscoveryProperties,
      Environment environment, RegistrationId registrationId) {
    return new NacosRegistration(dataCenterProperties, nacosDiscoveryProperties, environment, registrationId);
  }

  @Bean
  public NacosDiscovery nacosDiscovery(
      @Qualifier("nacosDiscoveryProperties") NacosDiscoveryProperties nacosDiscoveryProperties) {
    return new NacosDiscovery(nacosDiscoveryProperties);
  }
}
